# mltoolkit-laht 0.2.2

This is a Python library for data science and machine learning tasks. It provides utilities for data processing, modeling, and visualization.

## Installation

To install this package, clone the repository and run the setup script:

```
git clone https://github.com/lehidalgo/mltoolkit-laht
cd mltoolkit-laht
pip install .
```

## Usage

Full examples in Tutorials directory.

## Testing

To run the tests, use the following command:

```
python -m unittest discover tests
```

## Dependencies

This package requires the following Python libraries, which are listed in the `requirements.txt` file:

- numpy
- pandas
- scikit-learn
- matplotlib

Please make sure to install these dependencies before using this toolkit.

## Contributing

Contributions are welcome! Please submit a pull request or create an issue to propose changes or additions.
